@@ -194,6 +194,11 @@ gegl_sampler_linear_get (      GeglSampler       *self,
     gegl_sampler_linear_interpolate (self, absolute_x, absolute_y, result,
                                      repeat_mode);
 
-    babl_process (self->fish, result, output, 1);
+#if (BABL_MINOR_VERSION >=1) && (BABL_MICRO_VERSION >= 90)
+    self->fish_process 
+#else
+    babl_process
+#endif
+     (self->fish, (void*)result, (void*)output, 1, NULL);
   }
 }
